# webch: Web Characters, version 0.1  (C) 23-6-2003 Daniel Clemente Laboreo
# webch: Change strange characters of web pages to ISO-Latin1
# www.danielclemente.com/webch   danielclemente@ozu.es
# This program is GPL; you can modify it at your own.

# You need awk and basename (from coreutils) to run the script.

# TODO:
# * Solve the DO-NOT-CHANGE-TAGS thing, maybe by using another language -C- or using tricky tricks with diff, awk and patch (I have some ideas)
# * Accept input from pipes
# * Learn about the euro symbol
# -u option for undoing changes


echo "************************************************************************"
echo "* starting Web Characters 0.1        23th June 2003 by Daniel Clemente *"
echo "************ GPL'ed ****************** www.danielclemente.com/webch ****"
echo "                                              danielclemente@ozu.es"
echo
echo "Use: $0 files...  (example: $0 *.htm). Output goes to 'converted' dir"
echo
echo Remember this version will also change things like:
echo "<!-- Ao -->  to  <!-- A&ntilde;o -->"
echo "<IMG SRC=pingino.png>  to  <IMG SRC=ping&uuml;ino.png>"
echo  this is unwanted! But what did you hope of a 0.1 version?
echo "Anyway, wise webmasters don't use strange characters in paths."
echo

# The Convert function; it has to be declared here
Convert () {
	awk '{


	# Vowels with acute accent
	gsub (//, "\\&aacute;");
	gsub (//, "\\&eacute;");
	gsub (//, "\\&iacute;");
	gsub (//, "\\&oacute;");
	gsub (//, "\\&uacute;");

	gsub (//, "\\&Aacute;");
	gsub (//, "\\&Eacute;");
	gsub (//, "\\&Iacute;");
	gsub (//, "\\&Oacute;");
	gsub (//, "\\&Uacute;");

	# Vowels with grave accent
	gsub (//, "\\&agrave;");
	gsub (//, "\\&egrave;");
	gsub (//, "\\&igrave;");
	gsub (//, "\\&ograve;");
	gsub (//, "\\&ugrave;");

	gsub (//, "\\&Agrave;");
	gsub (//, "\\&Egrave;");
	gsub (//, "\\&Igrave;");
	gsub (//, "\\&Ograve;");
	gsub (//, "\\&Ugrave;");

	# Vowels with umlaut
	gsub (//, "\\&auml;");
	gsub (//, "\\&euml;");
	gsub (//, "\\&iuml;");
	gsub (//, "\\&ouml;");
	gsub (//, "\\&uuml;");

	gsub (//, "\\&Auml;");
	gsub (//, "\\&Euml;");
	gsub (//, "\\&Iuml;");
	gsub (//, "\\&Ouml;");
	gsub (//, "\\&Uuml;");

	# Vowels with circumflex accent
	gsub (//, "\\&acirc;");
	gsub (//, "\\&ecirc;");
	gsub (//, "\\&icirc;");
	gsub (//, "\\&ocirc;");
	gsub (//, "\\&ucirc;");

	gsub (//, "\\&Acirc;");
	gsub (//, "\\&Ecirc;");
	gsub (//, "\\&Icirc;");
	gsub (//, "\\&Ocirc;");
	gsub (//, "\\&Ucirc;");

	# C cedil used in french, catalan, ... Similar to "s"
	gsub (//, "\\&ccedil;");
	gsub (//, "\\&Ccedil;");
	
	# "Ee" used in spanish (pronounced as in "caNYon")
	gsub (//, "\\&ntilde;");
	gsub (//, "\\&Ntilde;");

	# To use at the beginning of long sentences ending with ! or ?
	gsub (//, "\\&iexcl;");
	gsub (//, "\\&iquest;");


	# The following are not so common
	
	# The accent marks themselves, without vowels
	gsub (//, "\\&acute;");
	# No, &grave; ( `````` ) is not supported by browsers... Why?
	gsub (//, "\\&uml;");
	gsub (/\^/, "\\&circ;");

	# We use this in catalan with leter l: "ll". Similar to "l"
	gsub (//, "\\&middot;");

	# As "1st" means "first", in spanish "1"="primero" and "1"="primera"
	gsub (//, "\\&ordm;");
	gsub (//, "\\&ordf;");

	# a-e ligature
	gsub (//, "\\&aelig;");
	gsub (//, "\\&AElig;");

	# Very nice for quotations
	gsub (//, "\\&laquo;");
	gsub (//, "\\&raquo;");


	# Currency symbols
	gsub (//, "\\&euro;"); # This does not work very well, tell me if you know something about it.
	gsub (//, "\\&cent;");
	gsub (//, "\\&pound;");
	gsub (//, "\\&yen;");
	
	# Use this to refer to sections (text paragrahs, for example)
	gsub (//, "\\&sect;");

	# Logical NOT (hypotheses, etc)
	gsub (//, "\\&not;");

	# Macron: indicates a longer sound for a vowel
	gsub (//, "\\&macr;");


	# Add your own changes here. E-mail me the missing ones!


	print;

	}' "$1" >converted/"`basename \"$1\"`"
	# basename strips the path and returns the file name.
	# It's in package coreutils. Install it, it's useful.

	echo ok
	
}


# HERE BEGINS THE SCRIPT

mkdir converted &> /dev/null
while [ $# -ne 0 ]
do
	echo -n ***\> PROCESSING: $1...\ 


	# Check if it's a good file
	
	if ! test -r "$1"
	then
		echo error! Can\'t read file. Skipping it.
		
	elif test -d "$1"
	then
		echo "directory! Recursive processing not yet implemented; use $0 \`find\`"

	else
		# Start the processing
		Convert "$1"
	fi

	
	shift


done
rmdir converted  &> /dev/null # (if it's empty)
# THE SCRIPT ENDS HERE. I hope you liked it.

